@@ -1,4 +1,4 @@
-# $Id: command.rb,v 1.7.2.2 2004/06/18 03:32:25 fdiary Exp $
+# $Id: command.rb,v 1.7.2.3 2004/06/26 14:11:23 fdiary Exp $
 # Copyright (C) 2002-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'amrita/template'
@@ -273,7 +273,7 @@ module Hiki
       @plugin.text = text
 
       data[:title]          = title( page )
-      data[:pagename]       = a( :value => page )
+      data[:pagename]       = a( :value => page.escapeHTML )
       data[:md5hex]         = a( :value => md5hex )
       data[:edit_proc]      = @plugin.edit_proc.sanitize
       data[:contents]       = @plugin.text.escapeHTML
@@ -301,7 +301,7 @@ module Hiki
       data = Hiki::Util::get_common_data( @db, @plugin )
       @plugin.hiki_menu(data, @cmd)
 
-      data[:title]        = title("#{@p.escapeHTML} #{msg_diff}")
+      data[:title]        = title("#{@p} #{msg_diff}")
       data[:differ]       = differ.sanitize
       generate_page( data )
     end
@@ -510,6 +510,12 @@ module Hiki
     end
 
     def admin_save_config
+      require 'hiki/session'
+      session_id = @params['session_id'][0]
+      if !session_id || !Hiki::Session.new( session_id ).check
+        admin_enter_password
+        return
+      end
       $site_name      = @params['site_name'][0]
       $author_name    = @params['author_name'][0]
       $mail           = @params['mail'][0]
@@ -527,14 +533,6 @@ module Hiki
       $theme_url      = @params['theme_url'][0]
       $theme_path     = @params['theme_path'][0]
 
-      if $password.size > 0
-        require 'hiki/session'
-        session_id = @params['session_id'][0]
-        if !session_id || !Hiki::Session.new( session_id ).check
-          admin_enter_password
-          return
-        end
-      end
       if password1.size > 0
         if ($password.size > 0 && old_password.crypt( $password ) != $password) ||
            (password1 != password2)
