@@ -1,6 +1,31 @@
-# $Id: global.rb,v 1.3 2004/02/15 02:48:35 hitoshi Exp $
+# $Id: global.rb,v 1.3.2.2 2004/06/19 09:21:37 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
+# default values
+$index_page    ||= ''
+$smtp_server   ||= 'localhost'
+$use_plugin    ||= false
+$site_name     ||= 'hoge hoge'
+$author_name   ||= ''
+$main_on_update||= false
+$mail          ||= ''
+$theme         ||= 'hiki'
+$theme_url     ||= 'theme'
+$theme_path    ||= 'theme'
+$use_sidebar   ||= false
+$main_class    ||= 'main'
+$sidebar_class ||= 'sidebar'
+$auto_link     ||= false
+$cache_path    ||= "#{$data_path}/cache"
+$style         ||= 'default'
+$hilight_keys  ||= true
+$plugin_debug  ||= false
+$charset       ||= 'EUC-JP'
+$lang          ||= 'ja'
+$database_type ||= 'flatfile'
+$cgi_name      ||= './'
+$options         = {} unless $options.class == Hash
+
 $template_path   = "#{$path}/template/#{$lang}"
 $plugin_path     = "#{$path}/plugin"
 $config_file     = "#{$data_path}/hiki.conf"
