@@ -1,5 +1,5 @@
-# $Id: page.rb,v 1.3 2003/03/23 03:37:12 hitoshi Exp $
-# Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
+# $Id: page.rb,v 1.4 2004/02/15 02:48:35 hitoshi Exp $
+# Copyright (C) 2002-2004 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'cgi'
 
@@ -16,20 +16,27 @@ module Hiki
     def to_html
       tmpl = TemplateFile.new @template
       html = ''
-#      tmpl = TemplateFileWithCache[template]
+#      tmpl = TemplateFileWithCache[@template]
 #      tmpl.use_compiler = true
-#      tmpl.set_hint_by_sample_data(data)
+#      tmpl.set_hint_by_sample_data(@contents)
       tmpl.expand_attr = true
       tmpl.expand(html, @contents)
       html
     end
 
-    def page( plugin, last_modified )
+    def page( plugin )
+      $title = @contents[:title]
       @contents[:header]         = plugin.header_proc.sanitize
       @contents[:body_leave]     = plugin.body_leave_proc.sanitize
+      @contents[:footer]         = plugin.footer_proc.sanitize
+      
       html = to_html
       header = Hash::new
-      header['Last-Modified']    = CGI::rfc1123_date(last_modified) if last_modified
+# XREA
+#      if @contents[:last_modified] and /HEAD/i =~ @cgi.request_method
+#       header['Last-Modified']    = CGI::rfc1123_date(@contents[:last_modified])
+#      end
+      header['Last-Modified']    = CGI::rfc1123_date(@contents[:last_modified])
       header['type']     = 'text/html'
       header['charset']          = $charset
       header['Content-Length']   = html.size.to_s
