@@ -1,4 +1,4 @@
-# $Id: session.rb,v 1.1.2.1 2004/06/18 03:32:25 fdiary Exp $
+# $Id: session.rb,v 1.1.2.2 2004/06/26 14:11:23 fdiary Exp $
 # Copyright (C) 2004 Kazuhiko <kazuhiko@fdiary.net>
 
 module Hiki
@@ -16,7 +16,7 @@ module Hiki
         @session_id = create_new_id
         # remove old session files
         Dir.mkdir( session_path ) unless test( ?e,  session_path )
-        Dir.glob( "#{session_path}*" ).each do |file|
+        Dir.glob( "#{session_path}/*" ).each do |file|
           File.delete( file.untaint )
         end
         # create a new session file
@@ -35,11 +35,11 @@ module Hiki
 
     private
     def session_path
-      "#{$data_path}/session/"
+      "#{$data_path}/session"
     end
 
     def session_file
-      "#{session_path}#{@session_id}".untaint
+      "#{session_path}/#{@session_id}".untaint
     end
 
     # (from cgi/session.rb)
