@@ -1,4 +1,4 @@
-# $Id: util.rb,v 1.8.2.1 2004/06/10 14:58:07 fdiary Exp $
+# $Id: util.rb,v 1.8.2.3 2004/06/27 10:58:03 fdiary Exp $
 # Copyright (C) 2002-2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 
 require 'nkf'
@@ -102,16 +102,34 @@ module Hiki
     def save_config
       File::open($config_file, "w") do |f|
         %w($site_name $author_name $mail $theme $password $theme_url $sidebar_class $main_class $theme_path $mail_on_update $use_sidebar $auto_link).each do |c|
-          f.puts( %Q|#{c} = #{eval(c).inspect}| ) if c
+          case eval(c).class.to_s
+          when "String"
+            f.puts( %Q|#{c} = #{eval(c).dump}| )
+          when "TrueClass", "FalseClass", "NilClass"
+            f.puts( %Q|#{c} = #{eval(c).inspect}| )
+          else
+            raise SecurityError, "Invalid configuration"
+          end
         end
       end
     end
 
     def load_config
+      variables = [:site_name, :author_name, :mail, :theme, :password,
+                   :theme_url, :sidebar_class, :main_class, :theme_path,
+                   :mail_on_update, :use_sidebar, :auto_link]
       begin
-        conf = File::readlines( $config_file ).join
-        eval( conf.untaint, binding, $config_file, 1 )
-      rescue
+        cgi_conf = File::readlines( $config_file ).join
+        cgi_conf.gsub!( /^\$/, '' )
+        def_vars = ''
+        variables.each do |var| def_vars << "#{var} = nil\n" end
+        eval( def_vars )
+        Thread.start {
+          $SAFE = 4
+          eval( cgi_conf, binding, "(hiki.conf)", 1 )
+        }
+        variables.each do |var| eval "$#{var} = #{var} if #{var} != nil" end
+      rescue IOError, Errno::ENOENT
       end
     end
 
@@ -120,7 +138,7 @@ module Hiki
     end
 
     def title( s )
-      "#{$site_name.escapeHTML} - #{s}"
+      "#{$site_name} - #{s}"
     end
 
     def view_title( s )
