@@ -1,4 +1,4 @@
-# $Id: attach.rb,v 1.2.2.1 2004/06/18 03:47:43 fdiary Exp $
+# $Id: attach.rb,v 1.2.2.2 2004/06/26 14:11:24 fdiary Exp $
 # Copyright (C) 2003 TAKEUCHI Hitoshi <hitoshi@namaraii.com>
 #
 # thanks to Kazuhiko, Masao Mutoh, SHIMADA Mitsunobu, Yoshimi, ꤿ
@@ -29,7 +29,7 @@ def attach_form(s = '')
 <div class="form">
 <form class="nodisp" method="post" enctype="multipart/form-data" action="#{$farm_page or "./"}attach.cgi">
   <div>
-    <input type="hidden" name="p" value="#{@page}">
+    <input type="hidden" name="p" value="#{@page.escapeHTML}">
     <input type="hidden" name="cache_path" value="#{@cache_path}">
     <input type="hidden" name="command" value="#{command}">
     <input type="hidden" name="refresh" value="#{$index_page}">
@@ -203,12 +203,7 @@ end
 def attach_show_page_files_checkbox
   s =  ''
   if (files = attach_page_files).size > 0
-    s << %Q!<form method="post" enctype="multipart/form-data" action="#{$farm_page or "./"}attach.cgi">
-  <input type="hidden" name="p" value="#{@page}">
-  <input type="hidden" name="cache_path" value="#{@cache_path}">
-  <input type="hidden" name="command" value="#{@command == 'create' ? 'edit' : @command}">
-  <input type="hidden" name="refresh" value="#{$index_page}">
-  <p>#{attach_files_label}: 
+    s << %Q!<p>#{attach_files_label}: 
 !
     files.each do |file_name|
       f = file_name.unescape
@@ -218,9 +213,9 @@ def attach_show_page_files_checkbox
       when 'Shift_JIS'
 	f = file_name.unescape.to_sjis
       end
-      s << %Q! [<input type="checkbox" name="file_#{file_name}">#{attach_anchor(f)}] \n!
+      s << %Q! [<input type="checkbox" name="file_#{file_name}" value="true">#{attach_anchor(f)}] \n!
     end
-    s << %Q!<input type="submit" name="detach" value="#{detach_upload_label}">\n</p>\n</form>\n!
+    s << %Q!<input type="submit" name="detach" value="#{detach_upload_label}">\n</p>!
   end
   s
 end
