@@ -1,4 +1,4 @@
-# $Id: local_css.rb,v 1.1.2.2 2004/02/28 22:15:19 hitoshi Exp $
+# $Id: local_css.rb,v 1.1.2.4 2004/06/27 08:56:43 fdiary Exp $
 # Copyright (C) 2003 OZAWA Sakuro <crouton@users.sourceforge.jp>
 
 def about_local_css
@@ -19,8 +19,7 @@ add_header_proc {
   local_css = $options['local.css'] || 'local.css'
   local_theme_url = theme_url.sub(/(.*\/).*\.css$/, "\\1#{local_css}")
   <<-EOS
-  <link rel="stylesheet" type="text/css" href="#{$theme_url}/#{local_css}" media="all" />
-  <link rel="stylesheet" type="text/css" href="#{local_theme_url}" media="all" />
+  <link rel="stylesheet" type="text/css" href="#{$theme_url.escapeHTML}/#{local_css}" media="all">
+  <link rel="stylesheet" type="text/css" href="#{local_theme_url.escapeHTML}" media="all">
   EOS
 }
-
